summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/MainDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/MainDlg.h')
-rw-r--r--kmplot/kmplot/MainDlg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmplot/kmplot/MainDlg.h b/kmplot/kmplot/MainDlg.h
index 8609de0e..ed6e1b14 100644
--- a/kmplot/kmplot/MainDlg.h
+++ b/kmplot/kmplot/MainDlg.h
@@ -74,11 +74,11 @@ class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
public:
/** Constuctor.
* @param tqparentWidget tqparent widget for this part
* @param tqparent tqparent object
* @param name name of this dialog
*/
- MainDlg(TQWidget *tqparentWidget, const char *, TQObject *tqparent, const char *name);
+ MainDlg(TQWidget *parentWidget, const char *, TQObject *tqparent, const char *name);
/// Cleaning up a bit.
virtual ~MainDlg();
/// This class needs access to private members, too.
@@ -221,7 +221,7 @@ class KmPlotPartFactory : public KParts::Factory
public:
KmPlotPartFactory();
virtual ~KmPlotPartFactory();
- virtual KParts::Part* createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ virtual KParts::Part* createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *tqparent, const char *name,
const char *classname, const TQStringList &args );
static KInstance* instance();
@@ -74,11 +74,11 @@ class MainDlg : public KParts::ReadOnlyPart, virtual public MainDlgIface
public:
/** Constuctor.
- * @param tqparentWidget tqparent widget for this part
+ * @param parentWidget tqparent widget for this part
* @param tqparent tqparent object
* @param name name of this dialog